# Copyright (C) 2006-2008 Red Hat, Inc.
#
# This program is free software; you can redistribute
# it and/or modify it under the terms of version 2 of the
# GNU General Public License as published by the
# Free Software Foundation.

from syslog import openlog, closelog, syslog, \
		LOG_AUTH, LOG_PID, LOG_NDELAY, LOG_INFO, \
		LOG_WARNING, LOG_DEBUG

from conga_constants import LUCI_DEBUG_MODE, LUCI_DEBUG_VERBOSITY, \
	LUCI_DEBUG_NET

# Exception class for the LuciSyslog facility
class LuciSyslogError(Exception):
	def __init__(self, msg):
		Exception.__init__(self, msg)

# Facility that provides centralized syslog(3) functionality for luci
class LuciSyslog:
	def __init__(self):
		self.__init = 0
		try:
			openlog('luci', LOG_PID | LOG_NDELAY, LOG_AUTH)
			self.__init = 1
		except:
			raise LuciSyslogError, 'unable to setup syslog functionality.'

	def __del__(self):
		self.close()

	def initialized(self):
		return self.__init > 0

	def log_msg(self, pri, msg):
		if not self.__init:
			return
		msg_len = len(msg)
		if msg_len < 1:
			return

		while True:
			cur_len = min(msg_len, 800)
			cur_msg = msg[:cur_len]

			try:
				syslog(pri, cur_msg)
			except:
				pass

			msg_len -= cur_len
			if msg_len > 0:
				msg = msg[cur_len:]
			else:
				break

	def info(self, msg):
		self.log_msg(LOG_INFO, msg)

	def warn(self, msg):
		self.log_msg(LOG_WARNING, msg)

	def private(self, msg):
		self.log_msg(LOG_DEBUG, msg)

	def debug_verbose(self, msg):
		if LUCI_DEBUG_MODE is not True or LUCI_DEBUG_VERBOSITY < 2:
			return
		self.log_msg(LOG_DEBUG, msg)

	def debug_net(self, msg):
		if LUCI_DEBUG_NET is not True or LUCI_DEBUG_VERBOSITY < 2:
			return
		self.log_msg(LOG_DEBUG, msg)

	def debug_net_priv(self, msg):
		if LUCI_DEBUG_NET is not True or LUCI_DEBUG_VERBOSITY < 3:
			return
		self.log_msg(LOG_DEBUG, msg)

	def debug(self, msg):
		if LUCI_DEBUG_MODE is not True:
			return
		self.log_msg(LOG_DEBUG, msg)

	def close(self):
		try:
			self.__init = 0
			closelog()
		except:
			pass

def get_logger():
	luci_logc = LuciSyslog()
	return luci_logc
